==> igniteui-react-charts-16.6.4.tgz: package/ES2015/igr-line-series.js <==
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { LineSeries } from "./LineSeries";
import { ensureEnum } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*
* `IgxLineSeriesComponent` belongs to a group of `IgxCategorySeriesComponent` and it is rendered using a collection of points connected by straight line segments.
*
* ```html
*  <igx-data-chart
*     [dataSource]="data">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-line-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-line-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxLineSeriesComponent = new IgxLineSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath = "value";
* this.chart.series.add(series);
* ```
*/
export class IgrLineSeries extends IgrHorizontalAnchoredCategorySeries {
    createImplementation() {
        return new LineSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Gets whether the `IgxSeriesComponent` shows an area or a line shape.
    *
    * ```ts
    * let isAreaOrLine: boolean = series.isAreaOrLine;
    * ```
    */
    get isAreaOrLine() {
        return this.i.ck;
    }
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgxSeriesComponent`. This can be set to `LinearInterpolate` to create a continous shape or `DontPlot` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         unknownValuePlotting="LinearInterpolate">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    get unknownValuePlotting() {
        return this.i.unknownValuePlotting;
    }
    set unknownValuePlotting(v) {
        this.i.unknownValuePlotting = ensureEnum(UnknownValuePlotting_$type, v);
    }
}

==> igniteui-react-charts-16.6.8.tgz: package/ES2015/igr-line-series.js <==
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { LineSeries } from "./LineSeries";
import { ensureEnum } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*
* `IgrLineSeries` belongs to a group of `IgrCategorySeries` and it is rendered using a collection of points connected by straight line segments.
*/
export class IgrLineSeries extends IgrHorizontalAnchoredCategorySeries {
    createImplementation() {
        return new LineSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Gets whether the `IgrSeries` shows an area or a line shape.
    *
    * ```ts
    * let isAreaOrLine: boolean = series.isAreaOrLine;
    * ```
    */
    get isAreaOrLine() {
        return this.i.ck;
    }
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgrSeries`. This can be set to `LinearInterpolate` to create a continous shape or `DontPlot` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    get unknownValuePlotting() {
        return this.i.unknownValuePlotting;
    }
    set unknownValuePlotting(v) {
        this.i.unknownValuePlotting = ensureEnum(UnknownValuePlotting_$type, v);
    }
}
